@@ -63,8 +63,11 @@ def format_coco_file(annotations):
             formatted_annotations[shape["image_id"]] = [shape]
     for image in annotations["images"]:
         tmp = image.copy()
-        tmp["annotations"] = formatted_annotations[image["id"]]
-        formatted_file["images"].append(tmp)
+        try:
+            tmp["annotations"] = formatted_annotations[image["id"]]
+            formatted_file["images"].append(tmp)
+        except KeyError:
+            pass
     return formatted_file
 
 
